@@ -6,7 +6,7 @@ import math
 import torch
 import torch.nn as nn
 import torch.nn.functional as F
-from torchvision.models.utils import load_state_dict_from_url
+from torch.hub import load_state_dict_from_url
 
 __all__ = [ 'carn', 'carn_m' ]
 
@@ -172,7 +172,7 @@ class CARNBlock(nn.Module):
         
 
 class CARN(nn.Module):
-    def __init__(self, scale, pretrained):
+    def __init__(self, scale, pretrained=False, map_location=None):
         super(CARN, self).__init__()
         
         multi_scale = True
@@ -197,7 +197,7 @@ class CARN(nn.Module):
         self.exit = nn.Conv2d(64, 3, 3, 1, 1)
 
         if pretrained:
-            self.load_pretrained()
+            self.load_pretrained(map_location=map_location)
                 
     def forward(self, x, scale=None):
         if self.scale is not None:
@@ -230,8 +230,12 @@ class CARN(nn.Module):
 
         return out
 
-    def load_pretrained(self):
-        state_dict = load_state_dict_from_url(urls["carn"], progress=True)
+    def load_pretrained(self, map_location=None):
+        if torch.cuda.is_available():
+            map_location = torch.device('cuda')
+        else:
+            map_location = torch.device('cpu')
+        state_dict = load_state_dict_from_url(urls["carn"], map_location=map_location, progress=True)
         self.load_state_dict(state_dict)
 
 
@@ -265,7 +269,7 @@ class CARNMBlock(nn.Module):
         
 
 class CARNM(nn.Module):
-    def __init__(self, scale, pretrained):
+    def __init__(self, scale, pretrained=False, map_location=None):
         super(CARNM, self).__init__()
         
         multi_scale = True
@@ -290,7 +294,7 @@ class CARNM(nn.Module):
         self.exit = nn.Conv2d(64, 3, 3, 1, 1)
 
         if pretrained:
-            self.load_pretrained()
+            self.load_pretrained(map_location=map_location)
                 
     def forward(self, x, scale=None):
         if self.scale is not None:
@@ -324,8 +328,10 @@ class CARNM(nn.Module):
 
         return out
 
-    def load_pretrained(self):
-        state_dict = load_state_dict_from_url(urls["carn_m"], progress=True)
+    def load_pretrained(self, map_location=None):
+        if not torch.cuda.is_available():
+            map_location = torch.device('cpu')
+        state_dict = load_state_dict_from_url(urls["carn_m"], map_location=map_location, progress=True)
         self.load_state_dict(state_dict)
 
 
