@@ -6,7 +6,7 @@
 import math
 import torch
 import torch.nn as nn
-from torchvision.models.utils import load_state_dict_from_url
+from torch.hub import load_state_dict_from_url
 
 __all__ = [ 'rcan', 'rcan_g10r20f64', ]
 
@@ -127,7 +127,7 @@ class ResidualGroup(nn.Module):
 
 ## Residual Channel Attention Network (RCAN)
 class RCAN(nn.Module):
-    def __init__(self, n_resgroups, n_resblocks, n_feats, reduction, scale, pretrained=False):
+    def __init__(self, n_resgroups, n_resblocks, n_feats, reduction, scale, pretrained=False, map_location=None):
         super(RCAN, self).__init__()
         self.scale = scale
         
@@ -168,7 +168,7 @@ class RCAN(nn.Module):
         self.tail = nn.Sequential(*modules_tail)
 
         if pretrained:
-            self.load_pretrained()
+            self.load_pretrained(map_location=map_location)
 
     def forward(self, x, scale=None):
         if scale is not None and scale != self.scale:
@@ -184,10 +184,14 @@ class RCAN(nn.Module):
 
         return x 
 
-    def load_pretrained(self):
+    def load_pretrained(self, map_location=None):
         if self.url is None:
             raise KeyError("No URL available for this model")
-        state_dict = load_state_dict_from_url(self.url, progress=True)
+        if torch.cuda.is_available():
+            map_location = torch.device('cuda')
+        else:
+            map_location = torch.device('cpu')
+        state_dict = load_state_dict_from_url(self.url, map_location=map_location, progress=True)
         self.load_state_dict(state_dict)
 
 
